@@ -8,8 +8,11 @@ use strictures 1;
 
 use Moose::Role;
 
+has 'gateway' => (is => 'ro');
+
 use WebService::Braintree::ErrorResult;
 use WebService::Braintree::Result;
+use WebService::Braintree::Util qw(to_instance_array);
 
 sub _make_request {
     my($self, $path, $verb, @args) = @_;
@@ -41,5 +44,12 @@ sub _make_raw_request {
     }
 }
 
+sub _array_request {
+    my ($self, $path, $key, $class) = @_;
+    my $response = $self->gateway->http->get($path);
+    my $attrs = $response->{$key} || [];
+    return to_instance_array($attrs, $class);
+}
+
 1;
 __END__
